/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.api.jbi.messaging.endpoint.exception;

import javax.xml.namespace.QName;

import org.ow2.petals.clientserverapi.jbi.messaging.endpoint.exception.EndpointDirectoryException;

/**
 * @author Christophe DENEUX - EBM WebSourcing
 */
public class EndpointAlreadyExistsException extends EndpointDirectoryException {

    private static final long serialVersionUID = 898804213056464035L;

    private static final String MESSAGE_PATTERN = "The endpoint '%s' for service '%s' already exists in the endpoint directory.";

    /**
     * Name of the already existing endpoint.
     */
    private final String existingEndpointName;

    /**
     * Service name of the already existing endpoint.
     */
    private final QName existingEndpointService;

    public EndpointAlreadyExistsException(final String existingEndpointName, final QName existingEndpointService) {
        super(String.format(MESSAGE_PATTERN, existingEndpointName, existingEndpointService.toString()));
        this.existingEndpointName = existingEndpointName;
        this.existingEndpointService = existingEndpointService;
    }

    public String getExistingEndpointName() {
        return this.existingEndpointName;
    }

    public QName getExistingEndpointService() {
        return this.existingEndpointService;
    }

}
